export async function load() {
    if (Editor.App.version !== '1.0.3') {
        return;
    }
    const profile = {
        default: Editor.Profile.load('default://packages/builder.json'),
        local: Editor.Profile.load('local://packages/builder.json'),
    };
    const lodash = require('lodash');
    const queues = profile.local.get('BuildTaskManager.queue');
    const platforms = ['wechatgame', 'web-mobile', 'web-desktop', 'oppo-mini-game', 'vivo-mini-game', 'huawei-mini-game'];
    if (Array.isArray(queues)) {
        queues.forEach((info: any) => {
            if (!platforms.includes(info.options.platform)) {
                return;
            }
            const name = info.options.platform;

            // 测试版出现过迁移错误
            if (info.options[name]) {
                lodash.set(info.options, `packages.${name}`, info.options[name]);
                delete info.options[name];
                return;
            }
            const defaultOptions = profile.default.get(`${info.options.platform}.${info.options.platform}`)
            Object.keys(info.options).forEach((key) => {
                if (defaultOptions && Object.keys(defaultOptions).includes(key)) {
                    lodash.set(info.options, `packages.${name}.${key}`, info.options[key]);
                    delete info.options[key];
                }
            });
        });
        // 本地存储数据迁移
        await Editor.Package.setConfig('builder', 'BuildTaskManager.queue', queues, 'local');
    }
}